==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateHeader.hpp <==
/*!**********************************************************************

  module: StudioWeb_TemplateHeader.hpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  logo header for WebQuery

  see also:		/

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

#ifndef STUDIOWEB_TEMPLATEHEADER_HPP
#define STUDIOWEB_TEMPLATEHEADER_HPP

/*
  -----------------------------------------------------------------------------
  includes
  -----------------------------------------------------------------------------
*/
#include "SAPDBCommon/Web/SAPDBWeb_Template.hpp"


class StudioWeb_TemplateHeader : public SAPDBWeb_Template 
{
  public:

    /*!-------------------------------------------------------------------------
      function:     StudioWeb_TemplateHeader
      
      description:  Constructor
      arguments:    [in] wa,webagent instance
      prototypes:   2
      -------------------------------------------------------------------------*/
     StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa);

     StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa,SAPDB_Bool bLogOff);
 
    /*!
      -------------------------------------------------------------------------
      function:     ~StudioWeb_TemplateHeader
      
      description:  Destructor
      -------------------------------------------------------------------------
     */
     ~StudioWeb_TemplateHeader();


  private:
     virtual SAPDB_Int2 askForWriteCount(const SAPDB_Char* szName);

     virtual const SAPDBWeb_String askForValue(const SAPDB_Char* szName);
                                              
  private:
    SAPDB_Bool m_bLogOff;
}; 

/*! EndClass: StudioWeb_TemplateHeader */

#endif // _StudioWeb_TemplateHeader_HPP_

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateHeader.hpp <==
/*!**********************************************************************

  module: StudioWeb_TemplateHeader.hpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  logo header for WebQuery

  see also:		/

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

#ifndef STUDIOWEB_TEMPLATEHEADER_HPP
#define STUDIOWEB_TEMPLATEHEADER_HPP

/*
  -----------------------------------------------------------------------------
  includes
  -----------------------------------------------------------------------------
*/
#include "ToolsCommon/Tools_Template.hpp"


class StudioWeb_TemplateHeader : public Tools_Template 
{
  public:

    /*!-------------------------------------------------------------------------
      function:     StudioWeb_TemplateHeader
      
      description:  Constructor
      arguments:    [in] wa,webagent instance
      prototypes:   2
      -------------------------------------------------------------------------*/
     StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa);

     StudioWeb_TemplateHeader(sapdbwa_WebAgent & wa,SAPDB_Bool bLogOff);
 
    /*!
      -------------------------------------------------------------------------
      function:     ~StudioWeb_TemplateHeader
      
      description:  Destructor
      -------------------------------------------------------------------------
     */
     ~StudioWeb_TemplateHeader();


  private:
     virtual SAPDB_Int2 askForWriteCount(const Tools_DynamicUTF8String &szName);

     virtual Tools_DynamicUTF8String askForValue(const Tools_DynamicUTF8String &szName);
                                              
  private:
    SAPDB_Bool m_bLogOff;
}; 

/*! EndClass: StudioWeb_TemplateHeader */

#endif // _StudioWeb_TemplateHeader_HPP_
